# secop-ophyd

This package allows seamless itegration of hardware that provides a SECoP interface into bluesky.


![secop-ophyd-arch](https://github.com/user-attachments/assets/cd82cfbe-68dc-4b3c-b872-5b1b7c7db82a)



## Getting Started 
A demo repository that shows the full functionality of the integration is provided here:

[secop-sim](https://codebase.helmholtz.cloud/rock-it-secop/secop-sim)


## Further information:

#### SECoP (https://github.com/SampleEnvironment/SECoP)
#### Frappy (https://github.com/SampleEnvironment/frappy)
